Index: trunk/Ohana/src/getstar/src/ConfigInit_overlaps.c
===================================================================
--- trunk/Ohana/src/getstar/src/ConfigInit_overlaps.c	(revision 41705)
+++ trunk/Ohana/src/getstar/src/ConfigInit_overlaps.c	(revision 41891)
@@ -44,5 +44,5 @@
   if (*CATFORMAT == 0) strcpy (CATFORMAT, "ELIXIR");
 
-  MAX_CERROR = 0.5; // arcseconds
+  MAX_CERROR = NAN; // NAN means do not cut on this value
   ScanConfig (config, "OVERLAPS_MAX_CERROR",     "%lf", 0, &MAX_CERROR);
 
Index: trunk/Ohana/src/getstar/src/MatchImages.c
===================================================================
--- trunk/Ohana/src/getstar/src/MatchImages.c	(revision 41705)
+++ trunk/Ohana/src/getstar/src/MatchImages.c	(revision 41891)
@@ -21,5 +21,6 @@
 
   // exclude chips / images with errors larger than OVERLAP_MAX_CERROR:
-  if (fabs(MAX_CERROR) > 1e-6) {
+  // 2021.11.03 : MAX_CERROR is now compared to the header value CERSTD
+  if (isfinite(MAX_CERROR)) {
     if (image[0].cerror * 0.02 > MAX_CERROR) return NULL;
   }
Index: trunk/Ohana/src/getstar/src/ReadImageHeader.c
===================================================================
--- trunk/Ohana/src/getstar/src/ReadImageHeader.c	(revision 41705)
+++ trunk/Ohana/src/getstar/src/ReadImageHeader.c	(revision 41891)
@@ -93,6 +93,8 @@
   }
     
-  /* CERROR in data file is in arcsec, image structure uses units of 20 mas */
-  if (!gfits_scan (header, "CERROR",   "%lf", 1, &tmp)) tmp = 1.0;
+  // CERROR & CERSTD in data file are in arcsec, image structure uses units of 20 mas
+  // if (!gfits_scan (header, "CERROR",   "%lf", 1, &tmp)) tmp = 1.0;
+  // 2021.11.03 : getstar now checks CERSTD, not CERROR
+  if (!gfits_scan (header, "CERSTD",   "%lf", 1, &tmp)) tmp = 1.0;
   image[0].cerror = tmp * 50.0;
  
